TdsCdc.Connection.Tds (tds_cdc v0.1.0)

Connection adapter that uses the tds library directly with a connection pool.

This is the default adapter when using conn: options.

Options

All options are forwarded to Tds.start_link/1, plus:

  • :pool_size - Number of connections in the pool (default: 5)
  • :ownership_timeout - Maximum time a connection can be checked out (default: 30_000ms)

Example

TdsCdc.start_link(
  conn: [hostname: "localhost", username: "sa", password: "pass", database: "mydb"],
  capture_instances: ["dbo_users"]
)